@@ -20,7 +20,8 @@
 #ifndef KNOTIFYCONFIGELEMENT_H
 #define KNOTIFYCONFIGELEMENT_H
 
-#include <QtCore/QMap>
+#include <QMap>
+#include <QString>
 
 class KConfig;
 class KConfigGroup;
@@ -35,19 +36,25 @@ public:
     KNotifyConfigElement(const QString &eventid, KConfig *config);
     ~KNotifyConfigElement();
 
+    KNotifyConfigElement(const KNotifyConfigElement &) = delete;
+    KNotifyConfigElement& operator=(const KNotifyConfigElement &) = delete;
+
     QString readEntry(const QString &entry, bool path = false);
     void writeEntry(const QString &entry, const QString &data);
 
+    QString eventId() const;
+
     void save();
 
     /**
-     * return wither kttsd is installed or not.
+     * Return whether Qt5TextToSpeech is installed or not.
      */
-    static bool have_kttsd();
+    static bool have_tts();
 
 private:
     QMap<QString, QString> m_cache;
     KConfigGroup *m_config;
+    QString m_eventId;
 };
 
 #endif
